@@ -36,7 +36,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.11.2_06'; # TRIAL VERSION
+our $VERSION = 'v0.11.3'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -60,6 +60,9 @@ use Path::Tiny 0.070    ();
 
 #pod =option minimum_perl
 #pod
+#pod Desired minimum Perl version. Extra test F<minimum-version.t> fails if actually required Perl
+#pod version is greater than desired.
+#pod
 #pod Optional, default value C<5.006>.
 #pod
 #pod =cut
@@ -197,7 +200,12 @@ has templates => (
 #pod
 #pod =option unwanted_modules
 #pod
-#pod TODO C<[ qw{ DDP Data::Printer } ]>.
+#pod C<Data::Printer> is a great module for debugging. But sometimes I forget to remove debug statements
+#pod from the code before release. This option helps to check it.
+#pod
+#pod If any of enlisted modules appears in the distribution dependencies, release will be aborted.
+#pod
+#pod Default value C<[ qw{ DDP Data::Printer } ]>.
 #pod
 #pod =cut
 
@@ -219,8 +227,8 @@ has unwanted_modules => (
 #pod =option spellchecker
 #pod
 #pod Command to run spellchecker. Spellchecker command is expected to read text from stdin, and print to
-#pod stdout misspelled words. If empty, spellchecking will be skipped. This involve C<Test::PodSpelling>
-#pod plugin and internally implemented checking the F<Changes> file.
+#pod stdout misspelled words. If empty, spellchecking will be skipped. This option affects
+#pod C<Test::PodSpelling> plugin and internally implemented checking the F<Changes> file.
 #pod
 #pod Optional, default value C<aspell list -l en -p ./xt/aspell-en.pws>.
 #pod
@@ -261,7 +269,9 @@ has repository => (
 
 #pod =option installer
 #pod
-#pod TODO
+#pod Installer plugin.
+#pod
+#pod Default value C<'ModuleBuildTiny'>.
 #pod
 #pod =cut
 
@@ -980,8 +990,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.11.2_06, released on 2016-12-15 22:13 UTC.
-This is a B<trial release>.
+Version v0.11.3, released on 2016-12-21 19:58 UTC.
 
 =head1 WHAT?
 
@@ -1005,6 +1014,9 @@ string literal, C<ArrayRef> attribute is converted to a list of string literals.
 
 =head2 minimum_perl
 
+Desired minimum Perl version. Extra test F<minimum-version.t> fails if actually required Perl
+version is greater than desired.
+
 Optional, default value C<5.006>.
 
 =head2 copying
@@ -1048,13 +1060,18 @@ Optional, default value C<[ ':InstallModules' ]>.
 
 =head2 unwanted_modules
 
-TODO C<[ qw{ DDP Data::Printer } ]>.
+C<Data::Printer> is a great module for debugging. But sometimes I forget to remove debug statements
+from the code before release. This option helps to check it.
+
+If any of enlisted modules appears in the distribution dependencies, release will be aborted.
+
+Default value C<[ qw{ DDP Data::Printer } ]>.
 
 =head2 spellchecker
 
 Command to run spellchecker. Spellchecker command is expected to read text from stdin, and print to
-stdout misspelled words. If empty, spellchecking will be skipped. This involve C<Test::PodSpelling>
-plugin and internally implemented checking the F<Changes> file.
+stdout misspelled words. If empty, spellchecking will be skipped. This option affects
+C<Test::PodSpelling> plugin and internally implemented checking the F<Changes> file.
 
 Optional, default value C<aspell list -l en -p ./xt/aspell-en.pws>.
 
@@ -1065,7 +1082,9 @@ push changes into several repositories. By default changes are pushed to one rep
 
 =head2 installer
 
-TODO
+Installer plugin.
+
+Default value C<'ModuleBuildTiny'>.
 
 =head1 WHY?
 
